package com.ruoyi.shipping.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

public class TCntrnoMessage extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /** 用户id */
    private Long fId;

    /** 箱号 */
    @Excel(name = "箱号")
    private String fNo;

    //箱类型中文
    @Excel(name = "箱类型")
    private String typeidName;

    //地点中文名称
    @Excel(name = "地点")
    private String addressName;

    //箱主中文
    @Excel(name = "箱主")
    private String ownerName;

    //箱来源中文
    @Excel(name = "箱来源")
    private String sourceName;

    //箱状态中文
    @Excel(name = "箱状态")
    private String cntrstatusName;

    //租赁方式中文
    @Excel(name = "租赁方式")
    private String rentName;

    //空重中文
    @Excel(name = "空重")
    private String updateEFName;

    /*备注*/
    @Excel(name = "备注")
    private String remark;

    /*创建者*/
    @Excel(name = "录入人")
    private String createBy;

    /* 创建时间*/
    @Excel(name = "录入时间",dateFormat = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date createTime;

    /* 更新者*/
    @Excel(name = "最新修改人")
    private String updateBy;

    /* 更新时间*/
    @Excel(name = "最新修改时间",dateFormat = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date updateTime;


    /** 箱类型（存t_cntr 编号 存储id） */
    private Long fTypeid;

    /** 箱主（选择数据字典 铁路凯和） */
    private String fOwner;

    /** 箱来源（数据字典 自由，租赁、买入、合作） */
    private String fSource;

    /** 租赁方式（数据字典 长租、短租） */
    private String fRent;

    /** 最新时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm")
    //@Excel(name = "最新时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date fUpdatetime;
    /** 造箱时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "造箱时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date fBuildBoxTime;

    /** 箱龄(年) */
    @Excel(name = "箱龄(年)")
    @JsonFormat(pattern = "yyyy")
    private String fBoxTurtleYear;

    /** 箱龄(月) */
    @Excel(name = "箱龄(月)")
    @JsonFormat(pattern = "MM")
    private String fBoxTurtleMonth;
    /** 箱公司 */
    @Excel(name = "箱主(手填)")
    private String fBoxLord;

    /** 合同协议号 */
    @Excel(name = "合同协议号")
    private String fPactDealHorn;

    /** 最新地点 */
    private String fUpdateaddress;
    /** 数据字典  空重 */
    private String fUpdateef;
    /** 数据字典 好 坏 */
    private String fCntrstatus;
    /** 默认 T ,正常T 停用F 下拉选择 */
    private String fStatus;
    /**数据字典 调箱动作*/
    private String fOpctnstatus;
    //铅封号
    private String fSealno;
    //提单号
    private String fMblno;
    //查询时间区间
    private List<String> cLoadDate;
    //集装箱尺码
    private Long cntrsize;
    //集装箱尺码中文
    private String cntrsizeName;
    //船名
    private String fVsl;
    //航次
    private String fVoy;
    //船ID
    private Long fVslid;
    //航次ID
    private Long fVoyid;
    //调入地点
    private String foldSite;
    //调入空重
    private String foldFUpdateef;
    //调入状态
    private String foldFCntrstatus;
    //调入时间
    private Date foldtime;
    //修改信息
    private List<TCntrno> tCntrno;
    //附件信息
    private List<TConditionAccessory> accessoryList;
    //调箱动作中文名
    private String opctnstatusName;
    //箱重量
    private BigDecimal fBoxWeight;
    //单航次配船修改状态 1 离港出运 2 到港卸船
    private Long updateStatus;
    //港口名称中文名
    private String portName;
    //港口名称
    private String port;
    /**
     * 是否按日志分组
     */
    private Integer whether = 0;

    public Integer getWhether() {
        return whether;
    }

    public void setWhether(Integer whether) {
        this.whether = whether;
    }

    public String getPort() {
        return port;
    }

    public void setPort(String port) {
        this.port = port;
    }

    public String getPortName() {
        return portName;
    }

    public void setPortName(String portName) {
        this.portName = portName;
    }

    public Long getfVslid() {
        return fVslid;
    }

    public void setfVslid(Long fVslid) {
        this.fVslid = fVslid;
    }

    public Long getfVoyid() {
        return fVoyid;
    }

    public void setfVoyid(Long fVoyid) {
        this.fVoyid = fVoyid;
    }

    public Long getUpdateStatus() {
        return updateStatus;
    }

    public void setUpdateStatus(Long updateStatus) {
        this.updateStatus = updateStatus;
    }

    public BigDecimal getfBoxWeight() {
        return fBoxWeight;
    }

    public void setfBoxWeight(BigDecimal fBoxWeight) {
        this.fBoxWeight = fBoxWeight;
    }

    public String getfBoxLord() {
        return fBoxLord;
    }

    public void setfBoxLord(String fBoxLord) {
        this.fBoxLord = fBoxLord;
    }

    public String getfPactDealHorn() {
        return fPactDealHorn;
    }

    public void setfPactDealHorn(String fPactDealHorn) {
        this.fPactDealHorn = fPactDealHorn;
    }

    public Date getfBuildBoxTime() {
        return fBuildBoxTime;
    }

    public void setfBuildBoxTime(Date fBuildBoxTime) {
        this.fBuildBoxTime = fBuildBoxTime;
    }

    public String getfBoxTurtleYear() {
        return fBoxTurtleYear;
    }

    public void setfBoxTurtleYear(String fBoxTurtleYear) {
        this.fBoxTurtleYear = fBoxTurtleYear;
    }

    public String getfBoxTurtleMonth() {
        return fBoxTurtleMonth;
    }

    public void setfBoxTurtleMonth(String fBoxTurtleMonth) {
        this.fBoxTurtleMonth = fBoxTurtleMonth;
    }

    public String getfSealno() {
        return fSealno;
    }

    public void setfSealno(String fSealno) {
        this.fSealno = fSealno;
    }

    public String getOpctnstatusName() {
        return opctnstatusName;
    }

    public void setOpctnstatusName(String opctnstatusName) {
        this.opctnstatusName = opctnstatusName;
    }

    public List<TConditionAccessory> getAccessoryList() {
        return accessoryList;
    }

    public void setAccessoryList(List<TConditionAccessory> accessoryList) {
        this.accessoryList = accessoryList;
    }

    public String getfOpctnstatus() {
        return fOpctnstatus;
    }

    public void setfOpctnstatus(String fOpctnstatus) {
        this.fOpctnstatus = fOpctnstatus;
    }

    public void setfId(Long fId)
    {
        this.fId = fId;
    }

    public Long getfId()
    {
        return fId;
    }
    public void setfNo(String fNo)
    {
        this.fNo = fNo;
    }

    public String getfNo()
    {
        return fNo;
    }
    public void setfTypeid(Long fTypeid)
    {
        this.fTypeid = fTypeid;
    }

    public Long getfTypeid()
    {
        return fTypeid;
    }
    public void setfOwner(String fOwner)
    {
        this.fOwner = fOwner;
    }

    public String getfOwner()
    {
        return fOwner;
    }
    public void setfSource(String fSource)
    {
        this.fSource = fSource;
    }

    public String getfSource()
    {
        return fSource;
    }
    public void setfRent(String fRent)
    {
        this.fRent = fRent;
    }

    public String getfRent()
    {
        return fRent;
    }
    public void setfUpdatetime(Date fUpdatetime)
    {
        this.fUpdatetime = fUpdatetime;
    }

    public Date getfUpdatetime()
    {
        return fUpdatetime;
    }
    public void setfUpdateaddress(String fUpdateaddress)
    {
        this.fUpdateaddress = fUpdateaddress;
    }


    public String getfUpdateaddress()
    {
        return fUpdateaddress;
    }
    public void setfUpdateef(String fUpdateef)
    {
        this.fUpdateef = fUpdateef;
    }

    public String getfUpdateef()
    {
        return fUpdateef;
    }
    public void setfCntrstatus(String fCntrstatus)
    {
        this.fCntrstatus = fCntrstatus;
    }

    public String getfCntrstatus()
    {
        return fCntrstatus;
    }
    public void setfStatus(String fStatus)
    {
        this.fStatus = fStatus;
    }

    public String getfStatus()
    {
        return fStatus;
    }

    public String getfMblno() {
        return fMblno;
    }

    public void setfMblno(String fMblno) {
        this.fMblno = fMblno;
    }

    public String getOwnerName() {
        return ownerName;
    }

    public void setOwnerName(String ownerName) {
        this.ownerName = ownerName;
    }

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    public String getRentName() {
        return rentName;
    }

    public void setRentName(String rentName) {
        this.rentName = rentName;
    }

    public String getUpdateEFName() {
        return updateEFName;
    }

    public void setUpdateEFName(String updateEFName) {
        this.updateEFName = updateEFName;
    }

    public String getCntrstatusName() {
        return cntrstatusName;
    }

    public void setCntrstatusName(String cntrstatusName) {
        this.cntrstatusName = cntrstatusName;
    }

    public List<String> getcLoadDate() {
        return cLoadDate;
    }

    public void setcLoadDate(List<String> cLoadDate) {
        this.cLoadDate = cLoadDate;
    }

    public Long getCntrsize() {
        return cntrsize;
    }

    public void setCntrsize(Long cntrsize) {
        this.cntrsize = cntrsize;
    }

    public String getCntrsizeName() {
        return cntrsizeName;
    }

    public void setCntrsizeName(String cntrsizeName) {
        this.cntrsizeName = cntrsizeName;
    }

    public String getfVsl() {
        return fVsl;
    }

    public void setfVsl(String fVsl) {
        this.fVsl = fVsl;
    }

    public String getfVoy() {
        return fVoy;
    }

    public void setfVoy(String fVoy) {
        this.fVoy = fVoy;
    }

    public String getTypeidName() {
        return typeidName;
    }

    public void setTypeidName(String typeidName) {
        this.typeidName = typeidName;
    }

    public String getFoldSite() {
        return foldSite;
    }

    public void setFoldSite(String foldSite) {
        this.foldSite = foldSite;
    }

    public String getFoldFUpdateef() {
        return foldFUpdateef;
    }

    public void setFoldFUpdateef(String foldFUpdateef) {
        this.foldFUpdateef = foldFUpdateef;
    }

    public String getFoldFCntrstatus() {
        return foldFCntrstatus;
    }

    public void setFoldFCntrstatus(String foldFCntrstatus) {
        this.foldFCntrstatus = foldFCntrstatus;
    }

    public Date getFoldtime() {
        return foldtime;
    }

    public void setFoldtime(Date foldtime) {
        this.foldtime = foldtime;
    }

    public List<TCntrno> gettCntrno() {
        return tCntrno;
    }

    public void settCntrno(List<TCntrno> tCntrno) {
        this.tCntrno = tCntrno;
    }

    public String getAddressName() {
        return addressName;
    }

    public void setAddressName(String addressName) {
        this.addressName = addressName;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("fId", getfId())
                .append("fNo", getfNo())
                .append("fTypeid", getfTypeid())
                .append("fOwner", getfOwner())
                .append("fSource", getfSource())
                .append("fRent", getfRent())
                .append("fUpdatetime", getfUpdatetime())
                .append("fUpdateaddress", getfUpdateaddress())
                .append("fUpdateef", getfUpdateef())
                .append("fCntrstatus", getfCntrstatus())
                .append("fStatus", getfStatus())
                .append("createBy", getCreateBy())
                .append("createTime", getCreateTime())
                .append("updateBy", getUpdateBy())
                .append("updateTime", getUpdateTime())
                .append("remark", getRemark())
                .append("fBuildBoxTime", getfBuildBoxTime())
                .append("fBoxTurtleYear", getfBoxTurtleYear())
                .append("fBoxTurtleMonth", getfBoxTurtleMonth())
                .append("fMblno", getfMblno())
                .append("fBoxWeight", getfBoxWeight())
                .toString();
    }
}
